@@ -83,48 +83,49 @@ REST_CSRF_ENABLED = False
    The CSRF middleware accepts some configuration parameters that are used to
    adjust the workflow of the CSRF validation. The available options are:
 
-   \`CSRF_METHODS\`: HTTP methods against which the csrf check should run.
-   Defaults to \`['POST', 'PUT', 'PATCH', 'DELETE']\`.
+   \\`CSRF_SAFE_METHODS\\`: HTTP methods against which the csrf check should
+   NOT run.
+   Defaults to \\`['POST', 'PUT', 'PATCH', 'DELETE']\\`.
 
-   \`CSRF_HEADER\`: The name of the request header used for CSRF
-   authentication. Defaults to \`X-CSRF-Token\`.
+   \\`CSRF_HEADER\\`: The name of the request header used for CSRF
+   authentication. Defaults to \\`X-CSRF-Token\\`.
 
-   \`CSRF_COOKIE_NAME\`: The name of the request cookie used for CSRF
-   authentication. Defaults to \`_csrftoken\`.
+   \\`CSRF_COOKIE_NAME\\`: The name of the request cookie used for CSRF
+   authentication. Defaults to \\`_csrftoken\\`.
 
-   \`CSRF_COOKIE_MAX_AGE\`: The maximum time until the cookie expires. After
-   the expiration the cookie will be removed. Defaults to \`60*60*24*7*52\`
+   \\`CSRF_COOKIE_MAX_AGE\\`: The maximum time until the cookie expires. After
+   the expiration the cookie will be removed. Defaults to \\`60*60*24*7*52\\`
    (1 year).
 
-   \`CSRF_COOKIE_DOMAIN\`: The domain for which the CSRF cookie should be
-   valid. Defaults to \`flask.sessions.SessionInterface.get_cookie_domain\`.
+   \\`CSRF_COOKIE_DOMAIN\\`: The domain for which the CSRF cookie should be
+   valid. Defaults to \\`flask.sessions.SessionInterface.get_cookie_domain\\`.
 
-   \`CSRF_COOKIE_PATH\`: The url path for which the cookie is set. This is
+   \\`CSRF_COOKIE_PATH\\`: The url path for which the cookie is set. This is
    useful if you have multiple Flask instances running under the same hostname.
    They can use different cookie paths, and each instance will only see its own
    CSRF cookie.
-   Defaults to \`flask.sessions.SessionInterface.get_cookie_path\`.
+   Defaults to \\`flask.sessions.SessionInterface.get_cookie_path\\`.
 
-   \`CSRF_COOKIE_SAMESITE\`: Restrict if CSRF cookie should be sent along
-   requests coming from external sites. Defaults to \`SESSION_COOKIE_SAMESITE\`
-   configuation variable, if this is set to a not \`None\` value, or \`Lax\`.
-   Lax prevents sending cookies with CSRF-prone requests from external sites,
-   such as submitting a form.
+   \\`CSRF_COOKIE_SAMESITE\\`: Restrict if CSRF cookie should be sent along
+   requests coming from external sites. Defaults to
+   \\`SESSION_COOKIE_SAMESITE\\` configuation variable, if this is set to
+   a not \\`None\\` value, or \\`Lax\\`. Lax prevents sending cookies with
+   CSRF-prone requests from external sites, such as submitting a form.
 
-   \`CSRF_SECRET\`: Secret key to encode/decode csrf token. Defaults to
-   application \`SECRET_KEY\`.
+   \\`CSRF_SECRET\\`: Secret key to encode/decode csrf token. Defaults to
+   application \\`SECRET_KEY\\`.
 
-   \`CSRF_SECRET_SALT\`: The salt value used to encode/decode csrf token.
-   Defaults to \`invenio-csrf-token\`.
+   \\`CSRF_SECRET_SALT\\`: The salt value used to encode/decode csrf token.
+   Defaults to \\`invenio-csrf-token\\`.
 
-   \`CSRF_TOKEN_LENGTH\`: The length of the generated csrf token. Defaults to
-   \`12\`.
+   \\`CSRF_TOKEN_LENGTH\\`: The length of the generated csrf token. Defaults to
+   \\`12\\`.
 
-   \`CSRF_ALLOWED_CHARS\`: The allowed characters that can be included in the
-   generation of the csrf token. Defaults to \`string.ascii_letters\` +
-   \`string.digits\`.
+   \\`CSRF_ALLOWED_CHARS\\`: The allowed characters that can be included in the
+   generation of the csrf token. Defaults to \\`string.ascii_letters\\` +
+   \\`string.digits\\`.
 
-   \`CSRF_FORCE_SECURE_REFERER\`: Flag to disable secure referrer check. This
+   \\`CSRF_FORCE_SECURE_REFERER\\`: Flag to disable secure referrer check. This
    should used only in development if you run your UI application over HTTP.
-   Defaults to \`True\`.
+   Defaults to \\`True\\`.
 """
